pub async fn get_dom(__arg0: State<DevServerState>) -> impl IntoResponseExpand description
GET /rdesktop/agent/dom
Returns a full DOM snapshot of the current page. The snapshot is collected from the browser via the bridge script.
pub async fn get_dom(__arg0: State<DevServerState>) -> impl IntoResponseGET /rdesktop/agent/dom
Returns a full DOM snapshot of the current page. The snapshot is collected from the browser via the bridge script.