pub async fn poll_recording(__arg0: State<DevServerState>) -> impl IntoResponseExpand description
GET /rdesktop/agent/recording/poll
Alias used by the browser bridge to discover start/stop commands.
pub async fn poll_recording(__arg0: State<DevServerState>) -> impl IntoResponseGET /rdesktop/agent/recording/poll
Alias used by the browser bridge to discover start/stop commands.