stop_recording

Function stop_recording 

pub async fn stop_recording(
    __arg0: State<DevServerState>,
    request: Option<Json<RecordingStopRequest>>,
) -> impl IntoResponse
POST /rdesktop/agent/recording/stop

Stop and finalize the native recorder, or request the browser bridge to flush and finalize its MediaRecorder. Repeating this call is safe.