pub struct ScreenshotPublisher { /* private fields */ }Expand description
Publishes native renderer frames to the Agent API without making the HTTP server poll a file that may still be written by the renderer.
Implementations
Sourceimpl ScreenshotPublisher
impl ScreenshotPublisher
pub fn new() -> Self
Sourcepub fn publish_png(&self, png: &[u8])
pub fn publish_png(&self, png: &[u8])
Publish a complete PNG frame. Oversized or empty frames are rejected so a broken renderer cannot turn the Agent endpoint into an unbounded IPC sink.
pub fn generation(&self) -> u64
pub async fn latest(&self) -> Option<PublishedScreenshot>
pub async fn wait_for_next( &self, after_generation: u64, timeout: Duration, ) -> Option<PublishedScreenshot>